@@ -512,6 +512,10 @@ public:
     extra_alloc= 0;
     alloced= thread_specific= 0;
   }
+  Binary_string(Binary_string &&str) noexcept
+  {
+    move(str);
+  }
 
   ~Binary_string() { free(); }
 
@@ -856,6 +860,8 @@ public:
     Binary_string(str, len)
   { }
   String(const String &str) = default;
+  String(String &&str) noexcept
+   :Charset(std::move(str)), Binary_string(std::move(str)){}
 
   void set(String &str,size_t offset,size_t arg_length)
   {
